Crate leptos_forge

Crate leptos_forge 

leptos_forge helps you build a reliable web UI interfaces in Leptos.

No documented features in Cargo.toml

Re-exports

pub use app::*;
pub use navigation::*;
pub use section::*;
pub use story::*;

Modules

app
Base component of the application
navigation
Module provides a helpers to create navigation links in the application
section
Trait for grouping the [stories][Story] together
story
Defines story interface and all of fancy stuff that goes with it
views
Internal components of the leptos_forge